Language

Trait Language 

pub trait Language:
    Send
    + Sync
    + Sized
    + 'static {
    type Settings: Default + Send + Sync;
    type Workspace: Default + Send;

    const NAME: &'static str;

    // Provided methods
    fn finalize(_cx: &mut FinalizeContext<'_, Self>) -> Result<()> { ... }
    fn finalize_files(_tree: &mut GeneratedTree) -> Result<()> { ... }
    fn bundle_middleware(
        _tree: &mut GeneratedTree,
        _middleware: &[BundledMiddleware],
    ) -> Result<()> { ... }
}

Required Associated Constants

const NAME: &'static str

Required Associated Types

Provided Methods

fn finalize(_cx: &mut FinalizeContext<'_, Self>) -> Result<()>

fn finalize_files(_tree: &mut GeneratedTree) -> Result<()>

Adapt assembled generated files for the target runtime after middleware bundling and before explicit author source overlays. Default is unchanged.

fn bundle_middleware( _tree: &mut GeneratedTree, _middleware: &[BundledMiddleware], ) -> Result<()>

Bundle SDK-author runtime middleware and register it in generated clients. Called with package-relative output after finalization and post plugins.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors