pub struct MockRequestMatch {
pub headers: BTreeMap<String, String>,
pub query: BTreeMap<String, String>,
pub path: BTreeMap<String, String>,
pub body: Option<Value>,
}Expand description
Exact request predicates for a mock scenario.
Header, query, and path predicates are strings because HTTP transports are
string based. body deliberately remains JSON to allow a scenario to
match an entire structured request body without inventing another query
language.
Fields
headers: BTreeMap<String, String>query: BTreeMap<String, String>path: BTreeMap<String, String>body: Option<Value>Trait Implementations
Sourceimpl Clone for MockRequestMatch
impl Clone for MockRequestMatch
Sourceimpl Debug for MockRequestMatch
impl Debug for MockRequestMatch
Sourceimpl Default for MockRequestMatch
impl Default for MockRequestMatch
Sourceimpl<'de> Deserialize<'de> for MockRequestMatch
impl<'de> Deserialize<'de> for MockRequestMatch
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for MockRequestMatch
Sourceimpl PartialEq for MockRequestMatch
impl PartialEq for MockRequestMatch
Sourceimpl Serialize for MockRequestMatch
impl Serialize for MockRequestMatch
impl StructuralPartialEq for MockRequestMatch