pub fn normalize_api(api: &mut Api, root: &Value) -> MigrationReportExpand description
Normalize annotations for ordinary generation through the sidecar adapter.
pub fn normalize_api(api: &mut Api, root: &Value) -> MigrationReportNormalize annotations for ordinary generation through the sidecar adapter.