pub fn normalize_openapi(document: &mut Value) -> MigrationReportExpand description
Rewrite operation annotations in a bundled document without changing wire names.
pub fn normalize_openapi(document: &mut Value) -> MigrationReportRewrite operation annotations in a bundled document without changing wire names.